@@ -9,8 +9,11 @@
     ################################################################################
     #
     meta <- packageDescription("bdlim")
-    attachmsg <- paste("This is bdlim ",meta$Version,
-                       ".\n - For details see help(`bdlim-package`) or https://anderwilson.github.io/bdlim/.\n - A vignette is available at https://anderwilson.github.io/bdlim/articles/.",
-                       sep="")
+    attachmsg <- paste(
+      "This is bdlim ",
+      meta$Version,
+      ".\n - For details see help(`bdlim-package`) or https://anderwilson.github.io/bdlim/.\n - A vignette is available at https://anderwilson.github.io/bdlim/articles/.",
+      sep = ""
+    )
     packageStartupMessage(attachmsg, domain = NULL, appendLF = TRUE)
   }
